@@ -5,9 +5,9 @@ package A1z::HTML5::Template;
 # ABSTRACT: Fast/easy Web Apps in Perl
 
 
-our $NAME = " Fast and Easy Web Apps ";
+sub NAME { my $self = shift; my $NAME; $NAME = "Fast and Easy Web Apps"; return $NAME; }
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 
 
@@ -1519,6 +1519,8 @@ sub open_file
 		my $out;
 		
 		@data = <DATA>; 
+
+		close DATA;
 	
 		$out .= qq{\n<!--begin accord 112-->\n<div id="accordion1460" class="accordion">\n}; 
 		foreach my $line (@data) 
@@ -1531,7 +1533,7 @@ sub open_file
 			
 			$out .= qq{\t<h3>$h1</h3>\n\t<div>$div</div>\n} if $line; 
 		} 
-		$out .= qq{\t<h3>Powered by</h3>\n\t<div>Package HTML5</div>\n}; 
+		$out .= qq{\t<h3>Powered by</h3>\n\t<div>Perl/CPAN</div>\n}; 
 		
 		$out .= qq{</div>\n<!--end accord-->\n}; 
 		
@@ -1542,6 +1544,8 @@ sub open_file
 # end open_file
 
 
+
+
 sub edit_file
 {
 	my $self = shift;
@@ -1728,6 +1732,49 @@ sub write_file
 
 
 
+sub display_gallery_thumbnails
+{
+	my $self = shift;
+
+	my $out;
+
+	my %in;
+
+	%in = (
+		
+		error => "",
+
+		images_dir => "$sys{images_dir}",
+		thumbs_dir => "$sys{thumbs_dir}",
+		
+		images_url => "$sys{images_url}",
+		thumbs_url => "$sys{thumbs_url}",
+	);
+
+	if (-e -d "$in{images_dir}" and "$in{thumbs_dir}" )
+	{
+		opendir(TH, "$in{thumbs_dir}") or $in{error} .= qq{<p>$!</p>};
+		my @thumbs = readdir(TH);
+		close TH;
+
+		foreach ( @thumbs ) 
+		{
+			if ( $_ and $_ =~ /(.jpg|.gif|.jpeg)$/ )
+			{
+				$out .= qq{<a href="$in{images_url}/$_" title="$_" data-gallery> <img src="$in{thumbs_url}/$_" alt="Image $_" width="100" height="100"> </a> };
+			}
+		}
+	}
+	else
+	{
+		$in{error} .= qq{Image directory does not exist or inaccessible};
+	}
+
+	return $out;
+}
+# end display gallery thumbnails 
+
+
 
 
 
@@ -1749,7 +1796,7 @@ A1z::HTML5::Template - Fast/easy Web Apps in Perl
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -1819,8 +1866,14 @@ version 0.12
 
 =head1 NAME
 
+	Fast and Easy Web Apps.
+
 	"A1z::HTML5::Template" provides customizable HTML5 tags for creating "Fast and Easy Web Apps."
 
+=head2 VERSION
+
+	0.13
+
 =head1 Installation
 
 	cpan install A1z::HTML5::Template 
@@ -1942,9 +1995,13 @@ version 0.12
 
 =head2 body_accordion
 
-	body_accordion is misleading. It is not limited to accordion but all kinds of content.
+	The accordion in 'body_accordion' is misleading. It is not limited to just an accordion but all kinds of content.
 
-	C<<< say $h->body_accordion( $h->open_file("/path/to/app/open_file_example.txt", 'Type', 'h2 Heading') ); >>>
+	C<say $h->body_accordion( $h->open_file("/path/to/app/open_file_example.txt", 'Type', 'Heading') );>
+
+	C<say $h->body_accordion( $h->open_file("/path/to/app/open_file_example.txt", "table", "Name and Price");
+
+	C<say $h->body_accordion( $h->open_file("/path/to/app/open_file_example.txt", "tabs", "Space Saving Tabs");
 
 =head2 body_article
 
@@ -2021,11 +2078,11 @@ version 0.12
 
 =head2 html_bootstrap_bluimp
 
-	bootstrap gallery lightbox - content for <body>
+	bootstrap gallery lightbox controls for use immediately after C<body> tag
 
-	&html_bootstrap_bluimp;
+	C<&html_bootstrap_bluimp;>
 
-	for internal use. 
+	Used internally in C<$h->body()> 
 
 =head2 head
 
@@ -2043,7 +2100,7 @@ version 0.12
 
 	$h->create_accordion("path/to/file/containing/accordion/elements");
 
-	Uses open_file to load "file"
+	Uses open_file to load content from a text file
 
 =head2 open_file
 
@@ -2065,7 +2122,7 @@ version 0.12
 
 	Data is stored in simple text files in the app's home dir.  
 
-	We recommend creating a new file for editing/writing purpose; E.g., "TemplateAdmin.cgi"
+	We recommend creating a separate file for editing/writing purposes, e.g., "TemplateAdmin.cgi"
 
 	use lib '/path/to/app';
 
@@ -2091,7 +2148,7 @@ version 0.12
 		content => $h->edit_file( file => "/absolute/path/to/app/open_file_example.txt") 
 	);
 
-	# Save Customizations to file.
+	# Save Customizations back to the same file.
 
 	# include write_file if you submit form to the same file ( TemplateAdmin.cgi )
 
@@ -2111,6 +2168,17 @@ version 0.12
 
 	See documentation for 'edit_file.'
 
+=head2 display_gallery_thumbnails
+
+	my $images = $h->display_gallery_thumbnails(
+
+		images_dir => "{images_dir}",
+		thumbs_dir => "{thumbs_dir}",
+		
+		images_url => "{images_url}",
+		thumbs_url => "{thumbs_url}",
+	);
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-a1z-html5-template at rt.cpan.org>, or through
